==> ejc-bid-impl-3.0.0-20230103.063941-300-sources.jar: com/ejianc/business/bid/controller/external/StatisticController.java <==
package com.ejianc.business.bid.controller.external;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.bid.bean.*;
import com.ejianc.business.bid.consts.BidCommonConsts;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.service.*;
import com.ejianc.business.bid.utils.DateUtil;
import com.ejianc.business.bid.vo.ResultVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

@Controller
@RequestMapping("statistic")
public class StatisticController implements Serializable {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IInfoTrackService infoTrackService;
    @Autowired
    private IEnrollService enrollService;
    @Autowired
    private IPrequaliFicationService prequaliFicationService;
    @Autowired
    private IBiddingFileReviewService biddingFileReviewService;
    @Autowired
    private IBidFileReviewService bidFileReviewService;
    @Autowired
    private ISummaryService summaryService;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IOrgApi orgApi;

    /**
     * @param timeFlag
     * @Description getBidState 投标状态
     */
    @RequestMapping(value = "/getBidState", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<ResultVO>> getBidState(String timeFlag, Long orgId) {
        List<ResultVO> resultVOS = new ArrayList<>();
        Long _orgId = orgId == null ? InvocationInfoProxy.getOrgId() : orgId;
        List<Long> orgIdList = orgApi.findChildrenByParentId(_orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList());

        // 跟踪
        QueryWrapper<InfoTrackEntity> infoTrackWrapper = new QueryWrapper<>();
        infoTrackWrapper.in("org_id", orgIdList);
        infoTrackWrapper.eq("thisYear".equals(timeFlag), "YEAR(bill_date)", DateUtil.getYear());

        ArrayList<Integer> integers = new ArrayList<>();
        integers.add(1);
        integers.add(2);
        infoTrackWrapper.in("follow_state", integers);
        int infoCount = infoTrackService.count(infoTrackWrapper);
        ResultVO InfoTrackResultVO = new ResultVO("跟踪信息", infoCount);

        // 报名
        QueryWrapper<EnrollEntity> enrollWrapper = new QueryWrapper<>();
        enrollWrapper.in("org_id", orgIdList);
        enrollWrapper.eq("thisYear".equals(timeFlag), "YEAR(sign_date)", DateUtil.getYear());
        int entrollCount = enrollService.count(enrollWrapper);
        ResultVO enrollResultVO = new ResultVO("投标报名", entrollCount);

        // 招标评审
        QueryWrapper<BiddingFileReviewEntity> biddingFileFicationWrapper = new QueryWrapper<>();
        biddingFileFicationWrapper.in("org_id", orgIdList);
        biddingFileFicationWrapper.eq("thisYear".equals(timeFlag), "YEAR(review_date)", DateUtil.getYear());
        int count = biddingFileReviewService.count(biddingFileFicationWrapper);
        ResultVO biddingFileResultVO = new ResultVO("招标评审", count);

        // 投标评审
        QueryWrapper<BidFileReviewEntity> bidFileReviewWrapper = new QueryWrapper<>();
        bidFileReviewWrapper.in("org_id", orgIdList);
        bidFileReviewWrapper.eq("thisYear".equals(timeFlag), "YEAR(review_date)", DateUtil.getYear());
        int count1 = bidFileReviewService.count(bidFileReviewWrapper);
        ResultVO bidFileReviewFicationResultVO = new ResultVO("投标评审", count1);

        // 中标
        QueryWrapper<SummaryEntity> summaryWrapper = new QueryWrapper<>();
        summaryWrapper.in("org_id", orgIdList);
        summaryWrapper.eq("bid_result", 0);
        summaryWrapper.eq("thisYear".equals(timeFlag), "YEAR(win_bidding_date)", DateUtil.getYear());
        int count2 = summaryService.count(summaryWrapper);
        ResultVO summaryResultVO = new ResultVO("中标", count2);

        resultVOS.add(InfoTrackResultVO);
        resultVOS.add(enrollResultVO);
        resultVOS.add(biddingFileResultVO);
        resultVOS.add(bidFileReviewFicationResultVO);
        resultVOS.add(summaryResultVO);
        return CommonResponse.success(resultVOS);
    }

    /**
     * @param timeFlag
     * @Description getBidSurvey 投标统计
     */
    @RequestMapping(value = "/getBidSurvey", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<ResultVO>> getBidSurvey(String timeFlag, Long orgId) {
        List<ResultVO> resultVOS = new ArrayList<>();
        List<String> billStates = Arrays.asList("0", "1", "2", "3", "5");
        Long _orgId = orgId == null ? InvocationInfoProxy.getOrgId() : orgId;
        List<Long> orgIdList = orgApi.findChildrenByParentId(_orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList());

        // 投标总数
        List<EnrollEntity> enrollList = new ArrayList<>();
        QueryWrapper<EnrollEntity> enrollWrapper = new QueryWrapper<>();
        enrollWrapper.in("org_id", orgIdList);
        enrollWrapper.in("bill_state",billStates);
        enrollWrapper.eq("thisYear".equals(timeFlag), "YEAR(sign_date)", DateUtil.getYear());
        enrollList = enrollService.list(enrollWrapper);
        ResultVO enrollResultVO = new ResultVO("投标总数", enrollList.size());

        LocalDate today = LocalDate.now();
        //近十天规则为过去三天和未来七天
        LocalDate afterOneWeekDay = today.plusDays(6);
        LocalDate beforeThreeDay = today.minusDays(3);
        LocalDate afterOneMonthDay = today.plusDays(29);
        // 近一月预计开标数
        QueryWrapper<EnrollEntity> monthWrapper = new QueryWrapper<>();
        monthWrapper.in("org_id", orgIdList);
        monthWrapper.in("bill_state",billStates);
        monthWrapper.eq("bid_state", BidStateEnum.JIN_XING_ZHONG.getCode());
        monthWrapper.ge("bidding_date", today.toString());
        monthWrapper.le("bidding_date", afterOneMonthDay.toString());
        int count1 = enrollService.count(monthWrapper);
        ResultVO collectResultVO = new ResultVO("近一月预计开标数", count1);

        // 近一周预计开标数
        QueryWrapper<EnrollEntity> weekWrapper = new QueryWrapper<>();
        weekWrapper.in("org_id", orgIdList);
        weekWrapper.in("bill_state",billStates);
        weekWrapper.eq("bid_state", BidStateEnum.JIN_XING_ZHONG.getCode());
        weekWrapper.ge("bidding_date", beforeThreeDay.toString());
        weekWrapper.le("bidding_date", afterOneWeekDay.toString());
        int count2 = enrollService.count(weekWrapper);
        ResultVO weekResultVO = new ResultVO("近一周预计开标数", count2);

        // 中标数
        List<Long> enrollIds = new ArrayList<>();
        Integer bidSumNum = 0;
        for (EnrollEntity enroll : enrollList) {
            enrollIds.add(enroll.getId());
            Integer bidNum = enroll.getBidNum() != null ? enroll.getBidNum() : 0;
            bidSumNum += bidNum;
        }
        int count = 0;
        if (CollectionUtils.isNotEmpty(enrollIds)) {
            QueryWrapper<SummaryEntity> summaryWrapper = new QueryWrapper<>();
            summaryWrapper.in("org_id", orgIdList);
            summaryWrapper.in("bill_state",billStates);
            summaryWrapper.eq("bid_result", 0);
            summaryWrapper.in("bill_state", Arrays.asList(BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()));
            summaryWrapper.in("enroll_id", enrollIds);
            count = summaryService.count(summaryWrapper);
        }
        ResultVO summaryResultVO = new ResultVO("中标数", count);
        ResultVO bidSumNumVO = new ResultVO("投标总标段数", bidSumNum);

        resultVOS.add(bidSumNumVO);
        resultVOS.add(summaryResultVO);
        resultVOS.add(collectResultVO);
        resultVOS.add(weekResultVO);
        resultVOS.add(enrollResultVO);
        return CommonResponse.success(resultVOS);
    }


    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(org.apache.commons.lang3.StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }

    public static void main(String[] args) {
        LocalDate today = LocalDate.now();
        LocalDate beforeThreeDay = today.minusDays(3);
        LocalDate afterOneWeekDay = today.plusDays(6);
        LocalDate afterOneMonthDay = today.plusDays(29);
        System.out.println(today);
        System.out.println(afterOneMonthDay);
        System.out.println(beforeThreeDay);
        System.out.println(afterOneWeekDay);
    }

}

==> ejc-bid-impl-3.0.0-20231008.020252-374-sources.jar: com/ejianc/business/bid/controller/external/StatisticController.java <==
package com.ejianc.business.bid.controller.external;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.bid.bean.*;
import com.ejianc.business.bid.consts.BidCommonConsts;
import com.ejianc.business.bid.consts.BidStateEnum;
import com.ejianc.business.bid.service.*;
import com.ejianc.business.bid.utils.DateUtil;
import com.ejianc.business.bid.vo.ResultVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import java.io.Serializable;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

@Controller
@RequestMapping("statistic")
public class StatisticController implements Serializable {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IInfoTrackService infoTrackService;
    @Autowired
    private IEnrollService enrollService;
    @Autowired
    private IPrequaliFicationService prequaliFicationService;
    @Autowired
    private IBiddingFileReviewService biddingFileReviewService;
    @Autowired
    private IBidFileReviewService bidFileReviewService;
    @Autowired
    private ISummaryService summaryService;

    @Autowired
    private SessionManager sessionManager;
    @Autowired
    private IOrgApi orgApi;

    /**
     * @param timeFlag
     * @Description getBidState 投标状态
     */
    @RequestMapping(value = "/getBidState", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<ResultVO>> getBidState(String timeFlag, Long orgId) {
        List<ResultVO> resultVOS = new ArrayList<>();
        Long _orgId = orgId == null ? InvocationInfoProxy.getOrgId() : orgId;
        List<Long> orgIdList = orgApi.findChildrenByParentId(_orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList());
        List<String> billStates = Arrays.asList("1", "3");

        // 跟踪
        QueryWrapper<InfoTrackEntity> infoTrackWrapper = new QueryWrapper<>();
        infoTrackWrapper.in("org_id", orgIdList);
        infoTrackWrapper.in("bill_state",billStates);
        infoTrackWrapper.eq("thisYear".equals(timeFlag), "YEAR(bill_date)", DateUtil.getYear());

        ArrayList<Integer> integers = new ArrayList<>();
        integers.add(1);
        integers.add(2);
        infoTrackWrapper.in("follow_state", integers);
        int infoCount = infoTrackService.count(infoTrackWrapper);
        ResultVO InfoTrackResultVO = new ResultVO("跟踪信息", infoCount);

        // 报名
        QueryWrapper<EnrollEntity> enrollWrapper = new QueryWrapper<>();
        enrollWrapper.in("org_id", orgIdList);
        enrollWrapper.in("bill_state",billStates);
        enrollWrapper.eq("thisYear".equals(timeFlag), "YEAR(sign_date)", DateUtil.getYear());
        int entrollCount = enrollService.count(enrollWrapper);
        ResultVO enrollResultVO = new ResultVO("投标报名", entrollCount);

        // 招标评审
        QueryWrapper<BiddingFileReviewEntity> biddingFileFicationWrapper = new QueryWrapper<>();
        biddingFileFicationWrapper.in("org_id", orgIdList);
        biddingFileFicationWrapper.in("bill_state",billStates);
        biddingFileFicationWrapper.eq("thisYear".equals(timeFlag), "YEAR(review_date)", DateUtil.getYear());
        int count = biddingFileReviewService.count(biddingFileFicationWrapper);
        ResultVO biddingFileResultVO = new ResultVO("招标评审", count);

        // 投标评审
        QueryWrapper<BidFileReviewEntity> bidFileReviewWrapper = new QueryWrapper<>();
        bidFileReviewWrapper.in("org_id", orgIdList);
        bidFileReviewWrapper.in("bill_state",billStates);
        bidFileReviewWrapper.eq("thisYear".equals(timeFlag), "YEAR(review_date)", DateUtil.getYear());
        int count1 = bidFileReviewService.count(bidFileReviewWrapper);
        ResultVO bidFileReviewFicationResultVO = new ResultVO("投标评审", count1);

        // 中标
        QueryWrapper<SummaryEntity> summaryWrapper = new QueryWrapper<>();
        summaryWrapper.in("org_id", orgIdList);
        summaryWrapper.eq("bid_result", 0);
        summaryWrapper.in("bill_state",billStates);
        summaryWrapper.eq("thisYear".equals(timeFlag), "YEAR(win_bidding_date)", DateUtil.getYear());
        int count2 = summaryService.count(summaryWrapper);
        ResultVO summaryResultVO = new ResultVO("中标", count2);

        resultVOS.add(InfoTrackResultVO);
        resultVOS.add(enrollResultVO);
        resultVOS.add(biddingFileResultVO);
        resultVOS.add(bidFileReviewFicationResultVO);
        resultVOS.add(summaryResultVO);
        return CommonResponse.success(resultVOS);
    }

    /**
     * @param timeFlag
     * @Description getBidSurvey 投标统计
     */
    @RequestMapping(value = "/getBidSurvey", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<ResultVO>> getBidSurvey(String timeFlag, Long orgId) {
        List<ResultVO> resultVOS = new ArrayList<>();
        List<String> billStates = Arrays.asList("1", "3");
        Long _orgId = orgId == null ? InvocationInfoProxy.getOrgId() : orgId;
        List<Long> orgIdList = orgApi.findChildrenByParentId(_orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList());

        // 投标总数
        List<EnrollEntity> enrollList = new ArrayList<>();
        QueryWrapper<EnrollEntity> enrollWrapper = new QueryWrapper<>();
        enrollWrapper.in("org_id", orgIdList);
        enrollWrapper.in("bill_state",billStates);
        enrollWrapper.eq("thisYear".equals(timeFlag), "YEAR(sign_date)", DateUtil.getYear());
        enrollList = enrollService.list(enrollWrapper);
        ResultVO enrollResultVO = new ResultVO("投标总数", enrollList.size());

        LocalDate today = LocalDate.now();
        //近十天规则为过去三天和未来七天
        LocalDate afterOneWeekDay = today.plusDays(6);
        LocalDate beforeThreeDay = today.minusDays(3);
        LocalDate afterOneMonthDay = today.plusDays(29);
        // 近一月预计开标数
        QueryWrapper<EnrollEntity> monthWrapper = new QueryWrapper<>();
        monthWrapper.in("org_id", orgIdList);
        monthWrapper.in("bill_state",billStates);
        monthWrapper.eq("bid_state", BidStateEnum.JIN_XING_ZHONG.getCode());
        monthWrapper.ge("bidding_date", today.toString());
        monthWrapper.le("bidding_date", afterOneMonthDay.toString());
        int count1 = enrollService.count(monthWrapper);
        ResultVO collectResultVO = new ResultVO("近一月预计开标数", count1);

        // 近一周预计开标数
        QueryWrapper<EnrollEntity> weekWrapper = new QueryWrapper<>();
        weekWrapper.in("org_id", orgIdList);
        weekWrapper.in("bill_state",billStates);
        weekWrapper.eq("bid_state", BidStateEnum.JIN_XING_ZHONG.getCode());
        weekWrapper.ge("bidding_date", beforeThreeDay.toString());
        weekWrapper.le("bidding_date", afterOneWeekDay.toString());
        int count2 = enrollService.count(weekWrapper);
        ResultVO weekResultVO = new ResultVO("近一周预计开标数", count2);

        // 中标数
        List<Long> enrollIds = new ArrayList<>();
        Integer bidSumNum = 0;
        for (EnrollEntity enroll : enrollList) {
            enrollIds.add(enroll.getId());
            Integer bidNum = enroll.getBidNum() != null ? enroll.getBidNum() : 0;
            bidSumNum += bidNum;
        }
        int count = 0;
        if (CollectionUtils.isNotEmpty(enrollIds)) {
            QueryWrapper<SummaryEntity> summaryWrapper = new QueryWrapper<>();
            summaryWrapper.in("org_id", orgIdList);
            summaryWrapper.in("bill_state",billStates);
            summaryWrapper.eq("bid_result", 0);
            summaryWrapper.in("bill_state", Arrays.asList(BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()));
            summaryWrapper.in("enroll_id", enrollIds);
            count = summaryService.count(summaryWrapper);
        }
        ResultVO summaryResultVO = new ResultVO("中标数", count);
        ResultVO bidSumNumVO = new ResultVO("投标总标段数", bidSumNum);

        resultVOS.add(bidSumNumVO);
        resultVOS.add(summaryResultVO);
        resultVOS.add(collectResultVO);
        resultVOS.add(weekResultVO);
        resultVOS.add(enrollResultVO);
        return CommonResponse.success(resultVOS);
    }

    /**
     * @param timeFlag
     * @Description getBidBase 经营门户-投标概况
     */
    @RequestMapping(value = "/getBidBase", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<List<ResultVO>> getBidBase(String timeFlag, Long orgId) {
        List<ResultVO> resultVOS = new ArrayList<>();
        List<String> billStates = Arrays.asList("1", "3");
        Long _orgId = orgId == null ? InvocationInfoProxy.getOrgId() : orgId;
        List<Long> orgIdList = orgApi.findChildrenByParentId(_orgId).getData().stream().map(OrgVO::getId).collect(Collectors.toList());

        //本年新增
        List<EnrollEntity> enrollList = new ArrayList<>();
        QueryWrapper<EnrollEntity> enrollWrapper = new QueryWrapper<>();
        enrollWrapper.in("org_id", orgIdList);
        enrollWrapper.in("bill_state",billStates);
        enrollWrapper.eq("thisYear".equals(timeFlag), "YEAR(sign_date)", DateUtil.getYear());
        enrollList = enrollService.list(enrollWrapper);
        //进行中
        List<EnrollEntity> enrollEndList = enrollList.stream().filter(s -> s.getBidState() != null && s.getBidState().equals(BidStateEnum.JIN_XING_ZHONG.getCode())).collect(Collectors.toList());

        //本年完成投标
        List<Long> enrollIds = new ArrayList<>();
        Integer bidSumNum = 0;
        for (EnrollEntity enroll : enrollList) {
            enrollIds.add(enroll.getId());
//            Integer bidNum = enroll.getBidNum() != null ? enroll.getBidNum() : 0;
//            bidSumNum += bidNum;
        }
        int count = 0;
        if (CollectionUtils.isNotEmpty(enrollIds)) {
            QueryWrapper<SummaryEntity> summaryWrapper = new QueryWrapper<>();
            summaryWrapper.in("org_id", orgIdList);
//            summaryWrapper.eq("bid_result", 0);
            summaryWrapper.in("bill_state", Arrays.asList(BillStateEnum.COMMITED_STATE.getBillStateCode(), BillStateEnum.PASSED_STATE.getBillStateCode()));
            summaryWrapper.in("enroll_id", enrollIds);
            count = summaryService.count(summaryWrapper);
        }


        ResultVO enrollResultVO = new ResultVO("本年新增", enrollList.size());
        ResultVO enrollEndVO = new ResultVO("进行中", enrollEndList.size());
        ResultVO summaryResultVO = new ResultVO("本年完成投标", count);
//        ResultVO bidSumNumVO = new ResultVO("投标总标段数", bidSumNum);

        resultVOS.add(summaryResultVO);
        resultVOS.add(enrollEndVO);
        resultVOS.add(enrollResultVO);
        return CommonResponse.success(resultVOS);
    }


    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(org.apache.commons.lang3.StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }

    public static void main(String[] args) {
        LocalDate today = LocalDate.now();
        LocalDate beforeThreeDay = today.minusDays(3);
        LocalDate afterOneWeekDay = today.plusDays(6);
        LocalDate afterOneMonthDay = today.plusDays(29);
        System.out.println(today);
        System.out.println(afterOneMonthDay);
        System.out.println(beforeThreeDay);
        System.out.println(afterOneWeekDay);
    }

}
